@@ -1,4 +1,5 @@
 import datetime
+import uuid as py_uuid
 
 import pytest
 import pytest_postgresql.factories
@@ -61,6 +62,7 @@ DummyBaseModel = make_base_model()
 
 def make_dummy_model():
     class Model(SQLModel):
+        dummy_uuid: py_uuid.UUID = Field(sa_column=sa.Column(sa_pg.UUID), default_factory=py_uuid.uuid4)
         dummy_str: str = Field(sa_column=sa.Column(sa_pg.VARCHAR(256)), default="")
         dummy_int: int = Field(sa_column=sa.Column(sa_pg.BIGINT), default=0)
         dummy_float: float = Field(sa_column=sa.Column(sa_pg.DOUBLE_PRECISION), default=0.0)
@@ -90,6 +92,7 @@ class DummySnapshotModel(DummyBaseModel, make_dummy_model(), make_snapshot_model
     __table_args__ = (
         snapshot_model_mixin.make_index_created_at_expired_at("ix_dummy_snapshot_model_created_at_expired_at"),
         snapshot_model_mixin.make_active_unique_index_record_sid("ix_au_dummy_snapshot_model_record_sid"),
+        snapshot_model_mixin.make_active_index_for("ix_a_dummy_snapshot_model_dummy_uuid", "dummy_uuid"),
     )
 
 
@@ -100,6 +103,7 @@ class DummyRevisionModel(DummyBaseModel, make_dummy_model(), make_revision_model
             "ix_dummy_revision_model_created_at_updated_at_expired_at"),
         revision_model_mixin.make_unique_index_record_sid_revision("ix_u_dummy_revision_model_record_sid_revision"),
         revision_model_mixin.make_active_unique_index_record_sid("ix_au_dummy_revision_model_record_sid"),
+        revision_model_mixin.make_active_index_for("ix_a_dummy_revision_model_dummy_uuid", "dummy_uuid"),
     )
 
 
@@ -147,6 +151,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             result = db_create_serial_model(session, DummySerialModel, create_records[i])
 
             assert result.sid == i + 1
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -158,6 +163,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             result = db_read_serial_model(session, DummySerialModel, i + 1)
 
             assert result.sid == i + 1
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -169,6 +175,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             result = db_update_serial_model(session, DummySerialModel, update_records[i], i + 1)
 
             assert result.sid == i + 1
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -181,6 +188,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
 
         for i, (result, update_record) in enumerate(zip(results, update_records)):
             assert result.sid == i + 1
+            assert result.dummy_uuid == update_record.dummy_uuid
             assert result.dummy_int == update_record.dummy_int
             assert result.dummy_str == update_record.dummy_str
             assert result.dummy_float == update_record.dummy_float
@@ -192,6 +200,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             result = db_read_serial_model(session, DummySerialModel, i + 1)
 
             assert result.sid == i + 1
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -203,6 +212,7 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             result = db_delete_serial_model(session, DummySerialModel, i + 1)
 
             assert result.sid == i + 1
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -263,6 +273,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -276,6 +287,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -293,6 +305,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -307,6 +320,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_record.dummy_uuid
             assert result.dummy_int == update_record.dummy_int
             assert result.dummy_str == update_record.dummy_str
             assert result.dummy_float == update_record.dummy_float
@@ -320,6 +334,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -333,6 +348,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
             assert result.sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -394,6 +410,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -412,6 +429,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_record.dummy_uuid
             assert result.dummy_int == create_record.dummy_int
             assert result.dummy_str == create_record.dummy_str
             assert result.dummy_float == create_record.dummy_float
@@ -426,6 +444,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -440,6 +459,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -458,6 +478,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -475,6 +496,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -489,6 +511,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -506,6 +529,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -524,6 +548,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -542,6 +567,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_record.dummy_uuid
             assert result.dummy_int == update_record.dummy_int
             assert result.dummy_str == update_record.dummy_str
             assert result.dummy_float == update_record.dummy_float
@@ -559,6 +585,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -579,6 +606,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -593,6 +621,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -607,6 +636,7 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.record_sid == i + 1
             assert result.created_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -667,6 +697,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -687,6 +718,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_record.dummy_uuid
             assert result.dummy_int == create_record.dummy_int
             assert result.dummy_str == create_record.dummy_str
             assert result.dummy_float == create_record.dummy_float
@@ -703,6 +735,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -719,6 +752,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -739,6 +773,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -758,6 +793,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -774,6 +810,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == create_records[i].dummy_uuid
             assert result.dummy_int == create_records[i].dummy_int
             assert result.dummy_str == create_records[i].dummy_str
             assert result.dummy_float == create_records[i].dummy_float
@@ -793,6 +830,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -813,6 +851,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -833,6 +872,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_record.dummy_int
             assert result.dummy_str == update_record.dummy_str
             assert result.dummy_float == update_record.dummy_float
@@ -852,6 +892,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -874,6 +915,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -890,6 +932,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-04T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at is None
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
@@ -906,6 +949,7 @@ def test_db_revision_model_crud(fixture_postgresql_test_proc, fixture_postgresql
             assert result.created_at == dt_parse_iso("2024-01-01T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.updated_at == dt_parse_iso("2024-01-02T00:00:00+00:00") + datetime.timedelta(days=i)
             assert result.expired_at == dt_parse_iso("2024-01-03T00:00:00+00:00") + datetime.timedelta(days=i)
+            assert result.dummy_uuid == update_records[i].dummy_uuid
             assert result.dummy_int == update_records[i].dummy_int
             assert result.dummy_str == update_records[i].dummy_str
             assert result.dummy_float == update_records[i].dummy_float
